from django.http import HttpResponse
from django.shortcuts import render

from django.views.generic.detail import DetailView
from django.views.generic.edit import CreateView, UpdateView

from .models import Announcement, Reaction

def announcement_view(request):
    announcements = Announcement.objects.order_by('-pub_datetime')
    context = {
        'announcements': announcements
    }
    return render(request, 'announcementboard/announcements.html', context)

class AnnouncementsCreateView(CreateView):
    model = Announcement
    template_name = 'announcementboard/announcement-add.html'
    fields = '__all__'

class AnnouncementsUpdateView(UpdateView):
    model = Announcement
    template_name = 'announcementboard/announcement-edit.html'
    fields = '__all__'

class AnnouncementsDetailView(DetailView):
    model = Announcement
    template_name = 'announcementboard/announcement-details.html'

    def get_context_data(self, **kwargs):
        context = super().get_context_data(**kwargs)
        reactions = Reaction.objects.filter(announcement=self.object)
        tallies = {
            'like': 0,
            'love': 0,
            'angry': 0
        }
        for reaction in reactions:
            if reaction.name == 'Like':
                tallies['like'] += reaction.tally
            elif reaction.name == 'Love':
                tallies['love'] += reaction.tally
            elif reaction.name == 'Angry':
                tallies['angry'] += reaction.tally
        context['tallies'] = tallies
        return context